# Copyright (C) 2007 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Code to ask the user for username and password"""

import threading

import inteproxy.main
from inteproxy.resources import gettext as _



# password cache and lock
pw_cache = {}
pw_lock = threading.Lock()

def get_password_with_cache(path):
    """Asks the user for username and password and cache the
    information.  The path parameter should be a string with hostname
    and path of the URL the caller is trying to access.  If a username
    and password for that string is already stored in the cache, the
    cached information is returned.  Otherwise this function uses the
    getpassword function to ask the user and then adds this information
    to the cache if the user didn't cancel, and then returns it.

    The return value is the tuple (username, password) or (None,
    None) if the user cancelled.
    """
    pw_lock.acquire()
    try:
        if path in pw_cache:
            user, password = pw_cache[path]
        else:
            title = _("Username for %s:") % path
            user, password = inteproxy.main.the_application.get_password(title)

            # cache the password if the user didn't cancel.
            if user is not None:
                pw_cache[path] = user, password

        return user, password
    finally:
        pw_lock.release()
