# Copyright (C) 2007 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Tests for OWSProxyPOSTTranscoder"""

import unittest
from inteproxy.transcoder import OWSProxyPOSTTranscoder


class TestOWSProxyPOSTTranscoder(unittest.TestCase):

    get_feature_orig = (
        '<?xml version="1.0" encoding="ISO-8859-1"?>'
        '<wfs:GetFeature'
        ' xmlns:ogc="http://www.opengis.net/ogc"'
        ' xmlns:gml="http://www.opengis.net/gml"'
        ' xmlns:wfs="http://www.opengis.net/wfs"'
        ' outputFormat="text/xml; subtype=gml/3.1.1">'
        '<wfs:Query'
        ' xmlns:app="http://www.deegree.org/app"'
        ' typeName="app:flurst">'
        '<wfs:PropertyName>app:the_geom</wfs:PropertyName>'
        '<wfs:PropertyName>app:objnr</wfs:PropertyName>'
        '</wfs:Query>'
        '</wfs:GetFeature>')

    get_feature_modified_template = (
        "<?xml version='1.0' encoding='ASCII'?>\n"
        '<wfs:GetFeature'
        ' xmlns:ogc="http://www.opengis.net/ogc"'
        ' xmlns:gml="http://www.opengis.net/gml"'
        ' xmlns:wfs="http://www.opengis.net/wfs"'
        ' outputFormat="text/xml; subtype=gml/3.1.1"'
        ' user=%(userattr)s password=%(passwordattr)s>'
        '<wfs:Query'
        ' xmlns:app="http://www.deegree.org/app"'
        ' typeName="app:flurst">'
        '<wfs:PropertyName>app:the_geom</wfs:PropertyName>'
        '<wfs:PropertyName>app:objnr</wfs:PropertyName>'
        '</wfs:Query>'
        '</wfs:GetFeature>')

    def test_username_password_substitution(self):

        class Transcoder(OWSProxyPOSTTranscoder):
            """
            An OWSProxyPOSTTranscoder that uses usernames/passwords
            defined in this test case
            """
            def get_password(self):
                return user, password


        test_users = [("user", "password", '"user"', '"password"'),
                      (u"some \xfcser&", "<pass&>word",
                       '"some &#252;ser&amp;"', '"&lt;pass&amp;&gt;word"'),
                      ]
        for user, password, userattr, passwordattr in test_users:
            transcoder = Transcoder("POST",
                                    ("https", "example.com", "wfs", "", ""))
            converted_body = transcoder.convert_body(None,
                                                     self.get_feature_orig)
            self.assertEquals(converted_body[1],
                              self.get_feature_modified_template % locals())
            self.assertEquals(converted_body[0],
                              "text/xml")
